<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fmp="http://www.filemaker.com/fmpxmlresult" exclude-result-prefixes="fmp">
<xsl:output method="text" version="1.0" encoding="mac" indent="no" omit-xml-declaration="yes"/>

<!--	
	rtf-biblio.xsl	(Notes de lecture, version 1.8 - novembre 2011 : modif police Times)
	===========
 	Transforme les donnees exportees de la table "biblios" en document rtf

	Parametres exportees dans dernier champ du record :
		-Titre de la bibliographie
		- infos sur les donnees (a ajouter en fin de doc)
		- regroupement des references par categorie (3e param -> $categON)
		- titres des publications en italique ou romain (4e param -> $italicON)

	Note : sans <xsl:strip-space elements="*"/> pour préserver retour ligne dans $infosDocument
-->


<!-- valeurs constantes 	-->
<xsl:variable name="openTagFM"> <xsl:text>[#|i|#]</xsl:text> </xsl:variable>
<xsl:variable name="closeTagFM"> <xsl:text>[#|/i|#]</xsl:text> </xsl:variable>
<xsl:variable name="openTagRTF"> <xsl:text>{\cs16\i </xsl:text> </xsl:variable>
<xsl:variable name="closeTagRTF"> <xsl:text>}</xsl:text> </xsl:variable>

<xsl:variable name="styleS1"> <xsl:text>\s1\qc \li0\ri0480\sb0\sa640\keepn\widctlpar\rin0\lin0\itap0 \f0\fs40\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 </xsl:text> </xsl:variable>
<xsl:variable name="styleS4"> <xsl:text>\s4\ql \li0\ri0\sb200\keepn\widctlpar\rin0\lin0\itap0 \b\f0\fs24\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 </xsl:text> </xsl:variable>
<xsl:variable name="styleBib"> <xsl:text>\s15\qj \fi-567\li567\ri0\sb100\widctlpar\rin0\lin567\itap0 \f0\fs22\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 </xsl:text> </xsl:variable>
<xsl:variable name="styleInfos"> <xsl:text>\s17\qr \li0\ri0\sb640 \widctlpar\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 </xsl:text> </xsl:variable>

<!--		PARAMETRES : extraction depuis la chaine des params exportes
		structure de la chaine : "titre[prm1]texte dernier paragraphe[prm2]booleen pour categ ON/OFF[prm3]"
-->
<xsl:variable name="params"> <xsl:value-of select="fmp:FMPXMLRESULT/fmp:RESULTSET/fmp:ROW[1]/fmp:COL[last()]"/> </xsl:variable>
<xsl:param name="titreDoc"><xsl:value-of select="substring-before($params,'[prm1]')"/></xsl:param>
<xsl:param name="infosDocument"><xsl:value-of select="substring-before(substring-after($params,'[prm1]'), '[prm2]')"/></xsl:param>
<xsl:param name="categON"><xsl:value-of select="substring-before(substring-after($params,'[prm2]'), '[prm3]')"/></xsl:param>
<xsl:param name="italicON"><xsl:value-of select="substring-before(substring-after($params,'[prm3]'), '[prm4]')"/></xsl:param>
<xsl:param name="nomStyleBib"><xsl:value-of select="substring-before(substring-after($params,'[prm4]'), '[prm5]')"/></xsl:param>
<xsl:param name="nomStylecar"><xsl:value-of select="substring-after($params,'[prm5]')"/></xsl:param>

<!--		CLE pour regroupement	-->
<xsl:key name="groupKey" match="fmp:FMPXMLRESULT/fmp:RESULTSET/fmp:ROW" use="fmp:COL[1]/fmp:DATA"/>




<!--		main template	-->
<xsl:template match="fmp:FMPXMLRESULT">

	<xsl:call-template name="header"/>


	<!--		titre page	-->
	<xsl:text>\pard\plain </xsl:text> <xsl:value-of select="$styleS1" /> <xsl:text>{</xsl:text>
	<xsl:value-of select="$titreDoc"/>
	<xsl:text> \par }</xsl:text>

	<xsl:choose>
	<!--			********** avec regroupement par categ -->
		<xsl:when test='$categON=1'>
			<xsl:for-each select="fmp:RESULTSET/fmp:ROW[generate-id(.)=generate-id(key('groupKey', fmp:COL[1]/fmp:DATA)[1])]">
				<xsl:variable name="currentGroup" select="key('groupKey', fmp:COL[1]/fmp:DATA)"/>
				<xsl:for-each select="$currentGroup">
					<!-- sous-titre categ si premier du groupe -->
					<xsl:if test="position()=1">
						<xsl:call-template name="Categorie"/>
					</xsl:if>
					<!-- ref -->
				<xsl:call-template name="RefBiblio">
					<xsl:with-param name="needForm" select ="$italicON"/>
				</xsl:call-template>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:when>

	<!--			********** sans regroupement -->
		<xsl:otherwise>
			<xsl:for-each select="fmp:RESULTSET/fmp:ROW">
				<xsl:call-template name="RefBiblio">
					<xsl:with-param name="needForm" select ="$italicON"/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:otherwise>
	</xsl:choose>

	<!--		fin de doc 	-->
	<xsl:text>\pard\plain </xsl:text> <xsl:value-of select="$styleInfos" /> <xsl:text>{</xsl:text>
	<xsl:value-of select="$infosDocument"/>
	<xsl:text>\par}</xsl:text>

	<!--		close rtf 	-->
	<xsl:text>}</xsl:text>
</xsl:template>



<!--	 en-tete rtf -->

<xsl:template name="header">
	<xsl:text>{\rtf1\mac\ansicpg10000\uc1 \deff0\stshfdbch0\stshfloch0\stshfhich0\stshfbi0\deflang1036\deflangfe1036
{\upr{\fonttbl
{\f0\fnil\fcharset256\fprq2{\*\panose 00020206030504050203}Times New Roman{\*\falt Times};}
{\f1\fnil\fcharset256\fprq2{\*\panose 00020b06040202020202}Arial;}
{\f4\fnil\fcharset256\fprq2{\*\panose 00020005000000000000}Times;}}
{\*\ud{\fonttbl
{\f0\fnil\fcharset256\fprq2{\*\panose 00020206030504050203}Times New Roman{\*\falt Times};}
{\f1\fnil\fcharset256\fprq2{\*\panose 00020b06040202020202}Arial;}
{\f4\fnil\fcharset256\fprq2{\*\panose 00020005000000000000}Times;}}
}}
{\colortbl;\red0\green0\blue0;\red0\green0\blue255;\red0\green255\blue255;\red0\green255\blue0;\red255\green0\blue255;
\red255\green0\blue0;\red255\green255\blue0;\red255\green255\blue255;\red0\green0\blue128;\red0\green128\blue128;\red0\green128\blue0;\red128\green0\blue128;\red128\green0\blue0;\red128\green128\blue0;\red128\green128\blue128;\red192\green192\blue192;}
{\stylesheet
	{\qj \li0\ri0\sb140 \widctlpar\rin0\lin0\itap0 \f0\fs22\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 \snext0 Normal;}
	{</xsl:text> <xsl:value-of select="$styleS1"/> <xsl:text>\sbasedon0 \snext0 heading 1;}
	{</xsl:text> <xsl:value-of select="$styleS4"/> <xsl:text>\sbasedon0 \snext15 heading 4;}
	{\*\cs10 \additive Default Paragraph Font;}
	{</xsl:text> <xsl:value-of select="$styleBib"/> <xsl:text>\sbasedon0 \snext15 </xsl:text><xsl:value-of select="$nomStyleBib"/><xsl:text>;}
	{\*\cs16 \additive \i \sbasedon10 </xsl:text> <xsl:value-of select="$nomStylecar"/><xsl:text>;}
	{\s17\qr \li0\ri0\sb640 \widctlpar\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 \sbasedon0 \snext17 infos;}
	{</xsl:text> <xsl:value-of select="$styleInfos"/> <xsl:text>\sbasedon0 \snext17 infos;}
	{\s22\qj \li0\ri0\sl-200\slmult0\widctlpar\tqr\tx9072\faauto\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 \sbasedon0 \snext22 header;}
	{\s23\qr \li0\ri0\sl-200\slmult0\widctlpar\tqr\tx9072\faauto\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 \sbasedon0 \snext23 footer;}
}
{\info
{\title Bibliographie}
{\subject NDL - export du fichier Biblios}
{\author Logiciel Notes de lecture}
{\operator Logiciel Notes de lecture}
{\*\company Universit\'8e Lyon 2, d\'8epartement des Lettres}
}
\paperw11906\paperh16838\margl1418\margr1418\margt1418\margb1418 
\deftab708\ftnbj\aenddoc\hyphhotz425
\noxlattoyen\expshrtn\noultrlspc\dntblnsbdb\nospaceforul
\hyphcaps0\hyphauto0\formshade
\horzdoc\dgmargin\dghspace180\dgvspace180\dghorigin1701\dgvorigin1984\dghshow0\dgvshow0
\jexpand\viewkind1\viewscale100\pgbrdrhead\pgbrdrfoot\splytwnine\ftnlytwnine\htmautsp\nolnhtadjtbl\useltbaln\alntblind\lytcalctblwd\lyttblrtgr\lnbrkrule\nobrkwrptbl \fet0\sectd 
\linex0\headery709\footery709\colsx708\endnhere\sectdefaultcl\sftnbj 
{\header \pard\plain \s22\qj \li0\ri0\sl-200\slmult0\widctlpar\tqr\tx9072\faauto\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 {\par }}
{\footer \pard\plain \s23\qr \li0\ri0\sl-200\slmult0\widctlpar\tqr\tx9072\faauto\rin0\lin0\itap0 \f0\fs18\lang1036\langfe1036\cgrid\langnp1036\langfenp1036 
{\field{\*\fldinst {PAGE }}{\fldrslt {\lang1024\langfe1024\noproof}}}{\par }
}
</xsl:text>
</xsl:template>


<!--	 une categorie -->

<xsl:template name="Categorie">
	<xsl:text>\pard\plain </xsl:text> <xsl:value-of select="$styleS4" /> <xsl:text>{</xsl:text>
	<xsl:value-of select="normalize-space(fmp:COL[1])"/>
	<xsl:text>\par }</xsl:text>
</xsl:template>


<!--	 une ref. bibliographique -->

<xsl:template name="RefBiblio">
<xsl:param name="needForm"/>
	<xsl:text>\pard\plain </xsl:text> <xsl:value-of select="$styleBib" /> <xsl:text>{</xsl:text>
	<xsl:choose>
		<xsl:when test="$needForm=1">
			<xsl:call-template name="replaceOpenAndCloseTags">
				<xsl:with-param name="str" select="normalize-space(fmp:COL[2])" />
				<xsl:with-param name="from" select ="$openTagFM"/>
				<xsl:with-param name="to" select ="$openTagRTF"/>
				<xsl:with-param name="from2" select ="$closeTagFM"/>
				<xsl:with-param name="to2" select ="$closeTagRTF"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="replaceOpenAndCloseTags">
				<xsl:with-param name="str" select="normalize-space(fmp:COL[2])" />
				<xsl:with-param name="from" select ="$openTagFM"/>
				<xsl:with-param name="to" select ="''"/>
				<xsl:with-param name="from2" select ="$closeTagFM"/>
				<xsl:with-param name="to2" select ="''"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>\par }</xsl:text>
</xsl:template>


<!--	 ****************** UTILITAIRES ****************** -->


<!--		replaceOpenAndCloseTags $str, $from, $to, $from2, $to2
		rech/remplacement d'un couple de chaine dans un paragraphe :		pour traitement des balises entourant passages a formater
-->
<xsl:template name="replaceOpenAndCloseTags">
	<xsl:param name="str"/>
	<xsl:param name="from"/>
	<xsl:param name="to"/>
	<xsl:param name="from2"/>
	<xsl:param name="to2"/>
	<xsl:choose>
		<xsl:when test="contains($str,$from)">
			<xsl:variable name="tmp">
				<xsl:call-template name="replaceString">
					<xsl:with-param name="str" select ="$str"/>
					<xsl:with-param name="from" select ="$from2"/>
					<xsl:with-param name="to" select ="$to2"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:value-of select="substring-before($tmp,$from)"/>
			<xsl:value-of select="$to"/>
			<xsl:call-template name="replaceString">
				<xsl:with-param name="str" select ="substring-after($tmp,$from)"/>
				<xsl:with-param name="from" select ="$from"/>
				<xsl:with-param name="to" select ="$to"/>
			</xsl:call-template>
		 </xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$str"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<!--	 	replaceString $str, $from, $to
		rech/remplacement simple dans une chaine (recursif)
-->
<xsl:template name="replaceString">
	<xsl:param name="str"/>
	<xsl:param name="from"/>
	<xsl:param name="to"/>
	<xsl:choose>
		<xsl:when test="contains($str,$from)">
			<xsl:value-of select="substring-before($str,$from)"/>
			<xsl:value-of select="$to"/>
			<xsl:call-template name="replaceString">
				<xsl:with-param name="str" select ="substring-after($str,$from)"/>
				<xsl:with-param name="from" select ="$from"/>
				<xsl:with-param name="to" select ="$to"/>
			</xsl:call-template>
		 </xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$str"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>